//
//  EMBExportController.h
//  EmberMac
//
//  Created by Damien DeVille on 02/10/2012.
//  Copyright (c) 2012 Realmac Software. All rights reserved.
//

#import <Cocoa/Cocoa.h>

#import "EMBEmberKit/EMBEmberLibraryPresenter.h"

typedef NS_OPTIONS(NSUInteger, EMBExportOption) {
	EMBExportOptionNone					= 0,
	EMBExportOptionSendViaAirDrop		= 1U << 0,
	EMBExportOptionComposeEmail			= 1U << 1,
	EMBExportOptionComposeMessage		= 1U << 2,
	EMBExportOptionExport				= 1U << 3,
	EMBExportOptionOpenInBrowser		= 1U << 4,
	EMBExportOptionPostOnFacebook		= 1U << 5,
	EMBExportOptionPostOnSinaWeibo		= 1U << 6,
	EMBExportOptionPostOnTwitter		= 1U << 7,
	EMBExportOptionUseAsDesktopPicture	= 1U << 8,
	EMBExportOptionAddToLibrary			= 1U << 9,
	EMBExportOptionUpload				= 1U << 10,
	EMBExportOptionAll					= NSUIntegerMax,
};

@class EMBPublishingController, EMBSnap, EMBSubscriptionItem, EMBUploadDestination, EMBEmberLibrary;

@interface EMBExportController : NSObject <EMBEmberLibraryPresenter>

@property (readonly, strong, nonatomic) NSOperationQueue *exportOperationQueue;
@property (readonly, strong, nonatomic) NSOperationQueue *publishingOperationQueue;

@property (readonly, strong, nonatomic) EMBPublishingController *publishingController;

@property (assign, nonatomic) IBOutlet NSMenu *recentUploadsMenu;

/*
	Export
 */
- (void)exportItems:(NSArray *)items presentationHandler:(void (^)(NSSavePanel *savePanel, void (^presentationCompletion)(NSInteger savePanelResult)))presentationHandler completionHandler:(void (^)(BOOL success, NSError *error))completionHandler;
- (void)shareItems:(NSArray *)items sharingServiceNamed:(NSString *)sharingServiceName presentationWindow:(NSWindow *)presentationWindow transitionsProvider:(void (^)(NSArray *sharingItems, void (^transitionsProviderCompletion)(NSArray *transitionImages, NSArray *transitionFrames)))transitionsProvider completionHandler:(void (^)(BOOL success, NSError *error))completionHandler;
- (void)publishItems:(NSArray *)items uploadDestination:(EMBUploadDestination *)uploadDestination;

/*
	Print
 */
- (void)printItems:(NSArray *)items presentationWindow:(NSWindow *)presentationWindow completionHandler:(void (^)(BOOL success, NSError *error))completionHandler;

/*
	External Editor
 */
- (void)viewItems:(NSArray *)items externalEditorIdentifier:(NSString *)externalEditorIdentifier completionHandler:(void (^)(BOOL success, NSError *error))completionHandler;

/*
	Backup
 */
- (void)createLibraryMetadataBackup:(EMBEmberLibrary *)library backupDirectory:(NSURL *)directoryLocation;
- (void)backupLibrary:(BOOL)backupSnapDocuments presentationHandler:(void (^)(NSSavePanel *savePanel, void (^presentationCompletion)(NSInteger savePanelResult)))presentationHandler;

@end

extern NSString * const EMBExportControllerNotificationPublishedURLStringKey;
extern NSString * const EMBExportControllerNotificationSnapURIRepresentationKey;
