//
//  EMBImportController.h
//  EmberMac
//
//  Created by Damien DeVille on 03/10/2012.
//  Copyright (c) 2012 Realmac Software. All rights reserved.
//

#import <Cocoa/Cocoa.h>

#import "EMBEmberKit/EMBEmberLibraryPresenter.h"

@class EMBEmberLibrary, EMBSubscriptionItem;

@interface EMBImportController : NSObject <EMBEmberLibraryPresenter>

- (id)initWithManagedObjectContext:(NSManagedObjectContext *)managedOjectContext emberLibrary:(EMBEmberLibrary *)emberLibrary;

@property (readonly, strong, nonatomic) NSOperationQueue *importOperationQueue;

- (void)importAssetsWithPresentationHandler:(void (^)(NSOpenPanel *savePanel, void (^presentationCompletion)(NSArray *URLs)))presentationHandler;

/*!
	\brief
	Import assets.
	Snaps metadata can either be a dictionary (in which case the same metadata will be applied to each snap)
	or an array (in that case, the snaps metadata array has to have the same count as the asset URLs)
 */
- (void)importAssetsAtLocations:(NSArray *)assetURLs snapsMetadata:(id)snapsMetadata completionHandler:(void (^)(BOOL success, NSError *error))completionHandler;

/*!
	\brief
	Import image.
 */
- (void)importImage:(NSImage *)image fileType:(NSString *)fileType snapMetadata:(NSDictionary *)snapMetadata completionHandler:(void (^)(BOOL success, NSError *error))completionHandler;

/*!
	\brief
	Download and import a remote image at a given URL.
 */
- (void)importRemoteImageAtURL:(NSURL *)imageURL snapMetadata:(NSDictionary *)snapMetadata completionHandler:(void (^)(BOOL success, NSError *error))completionHandler;

/*!
	\brief
	Import a subscription item
 */
- (void)importSubscriptionItem:(EMBSubscriptionItem *)subscriptionItem presentationWindow:(NSWindow *)presentationWindow completionHandler:(void (^)(BOOL success, NSError *error))completionHandler;

/*!
	\brief
	Start detection of a LittleSnapper library. The completion handler will be invoked on the main queue.
 */
- (void)detectLittleSnapperLibraryWithCompletionHandler:(void (^)(NSURL *libraryLocation, NSError *findingError))completionHandler;

/*!
	\brief
	Import a LittleSnapper library.
	The library location parameter can be nil, in which case the open panel won’t originally point to an actual library.
	The presentation handler will be invoked on the main queue whereas the completion handler could be invoked on any queue.
 */
- (void)importLittleSnapperLibraryAtLocation:(NSURL *)libraryLocation showOpenPanel:(BOOL)showOpenPanel presentationHandler:(void (^)(NSOpenPanel *savePanel, void (^presentationCompletion)(NSArray *URLs)))presentationHandler;

/*!
	\brief
	Prompt for selection of a LittleSnapper library
 */
- (NSOpenPanel *)openPanelForLittleSnapperLibrarySelectionAtLocation:(NSURL *)libraryLocation;

/*!
	\brief
	Update the thumbnail for a snap.
 */
- (void)updateCompositedImageForSnapObjectID:(NSManagedObjectID *)snapObjectID;

/*!
	\brief
	Restore a library from a backup that was previously saved at the given location.
 */
- (void)restoreLibraryFromBackupAtLocation:(NSURL *)backupLocation;

@end

extern NSString * const EMBImportControllerWillMergeCriticalChangesNotification;
extern NSString * const EMBImportControllerDidMergeCriticalChangesNotification;
