//
//  EMBEmberLibraryCoordinator.h
//  EmberCommon
//
//  Created by Damien DeVille on 16/06/2013.
//  Copyright (c) 2013 Realmac Software. All rights reserved.
//

#import <Foundation/Foundation.h>

@class NSPersistentStoreCoordinator, NSManagedObjectContext, NSManagedObject;
@class EMBEmberLibrary, EMBEmberLibraryConfiguration;

@interface EMBEmberLibraryCoordinator : NSObject <NSLocking>

/*!
	\brief
	Mount a library given a configuration.
	
	\param configuration
	A library configuration.
	
	\param error
	An error passed by reference.
 */
- (EMBEmberLibrary *)mountLibraryWithConfiguration:(EMBEmberLibraryConfiguration *)configuration error:(NSError **)errorRef;

/*!
	\brief
	Unmount a given library.
	
	\param library
	A mounted library.
	
	\param error
	An error passed by reference.
 */
- (BOOL)unmountLibrary:(EMBEmberLibrary *)library error:(NSError **)errorRef;

/*!
	\brief
	The libraries associated with the coordinator.
 */
- (NSArray *)libraries;

/*!
	\brief
	The persistent store coordinator associated with the Ember library coordinator.
 */
@property (readonly, strong, nonatomic) NSPersistentStoreCoordinator *persistentStoreCoordinator;

/*!
	\brief
	A managed object context of concurrency type `NSPrivateQueueConcurrencyType` associated with the persistent store coordinator.
 */
@property (readonly, strong, nonatomic) NSManagedObjectContext *rootManagedObjectContext;

/*!
	\brief
	A managed object context of concurrency type `NSMainQueueConcurrencyType` associated with the persistent store coordinator.
 */
@property (readonly, strong, nonatomic) NSManagedObjectContext *mainManagedObjectContext;

/*!
	\brief
	Return the library a managed object belongs to.
 */
+ (EMBEmberLibrary *)emberLibraryForManagedObject:(NSManagedObject *)managedObject;

/*!
	\brief
	Attempt to refresh Ensembles changes. It is a programmer error to call this method with a library that doesn't have Ensembles
 */
- (void)refreshEnsemblesForLibrary:(EMBEmberLibrary *)library completion:(void (^)(NSError *error))completion;

/*!
	\brief
	Mark the Ensembles associated with the library as needing a refresh. It is a programmer error to call this method with a library that doesn't have Ensembles
 */
- (void)setNeedsEnsemblesRefreshForLibrary:(EMBEmberLibrary *)library;

/*!
	\brief
	Deleech the Ensembles associated with the library. It is a programmer error to call this method with a library that doens't have Ensembles.
 */
- (void)deleechEnsemblesForLibrary:(EMBEmberLibrary *)library completion:(void (^)(NSError *error))completion;

@end

extern NSString * const EMBEmberLibraryCoordinatorLibrariesWillChangeNotification;
extern NSString * const EMBEmberLibraryCoordinatorLibrariesDidChangeNotification;
