//
//  RMSnapCenter.h
//  RMSnapKit
//
//  Created by Damien DeVille on 06/07/2012.
//	Copyright (c) 2012 Realmac Software. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <TargetConditionals.h>

#if !TARGET_OS_IPHONE

@class RMScreenSnapOperation;

@interface RMScreenSnapCenter : NSObject

typedef NS_ENUM(NSUInteger, RMScreenSnapType) {
	RMScreenSnapTypeDesktop = 0,
	RMScreenSnapTypeTimedDesktop = 1,
	RMScreenSnapTypeWindow = 2,
	RMScreenSnapTypeArea = 3,
	RMScreenSnapTypeRecord = 4,
};

typedef NS_OPTIONS(NSUInteger, RMScreenSnapOptionsMask) {
	RMScreenSnapOptionsMuteSound = 1 << 0,
	RMScreenSnapOptionsIncludeShadows = 1 << 1,
	RMScreenSnapOptionsIncludeAllAppWindows = 1 << 2,
	RMScreenSnapOptionsIncludeCursor = 1 << 3,
};

/*!
	\brief
	This method will present a panel to the user offering selection of a window or an area (based on the type).
	
	The user completion block is invoked with an operation when the selection has been made or nil if the user has cancelled.
	The operation passed in the block parameters is fully initialized but has not been added to any queue and not started.
	
	Returns YES if the screen snap can start. Returns NO if a screen snap is already in process and a new screen snap cannot thus be started.
 */
- (BOOL)screenSnapWithType:(RMScreenSnapType)type options:(RMScreenSnapOptionsMask)options userCompletionHandler:(void (^)(RMScreenSnapOperation *screenSnapOperation, NSError *error))userCompletionHandler;

/*!
	\brief
	User defaults to use to store preferences for the screen snapping.
	RMScreenSnapCenter will use [NSUserDefaults standardUserDefaults] if this is nil.
 */
@property (strong, nonatomic) NSUserDefaults *userDefaults;

/*!
	\brief
	An array of the current application's windows that should be hidden when snapping.
 */
@property (copy, nonatomic) NSArray *currentApplicationWindowsToHide;

/*!
	\brief
	Bundle indentifiers of applications that should be hidden when snapping.
 */
@property (copy, nonatomic) NSArray *bundleIdentifiersOfApplicationsToHide;

@end

#endif /* !TARGET_OS_IPHONE */
